/**
 * Плагин jQuery для создания плавающего виджета с кнопками.
 * Рассчитан на использование на страницах с фиксированной шириной.
 * Виджет будет появляться слева от основного содержимого. 
 * 
 * Использование:
 * 1) подключите библиотеку jQuery и плагин (с помощью тегов <script>)
 * 2) создайте на странице тег <div> с кодом кнопки и присвойте ему уникальный id
 * Например,
 * <div id="twitter_widget"><script type="text/javascript" src="http://tweetmeme.com/i/scripts/button.js"></script></div>
 * Здесь кнопка создаётся сервисом Tweetmeme (http://tweetmeme.com/about/retweet_button),
 * вы можете использовать любой другой сервис или обычную картинку.
 * 3) подключите плагин
 * $('#twitter_widget').left_floating_button();
 * 4) можно задавать следующие параметры
 * fromCenter - расстояние от середины страницы до середины виджета
 * fromTop - расстояние от виджета до верхней границы видимой части страницы
 * minTop - расстояние от виджета до начала страницы
 * 
 * Используются параметры следующим образом
 * $('#twitter_widget').left_floating_button({
 *  		'fromCenter': 520,
 *  		'fromTop': 50,
 *  		'minTop': 200
 *  	});
 *  
 *  Стаценко Владимир
 *  http://www.simplecoding.org/
 */
(function($) {
    $.fn.left_floating_button = function(settings) {
    	//значения по-умолчанию
    	var config = {
    		'fromCenter': 520,
    		'fromTop': 50,
    		'minTop': 200
    	};
    	//если пользователь указал свои параметры, то используем их
        if (settings) $.extend(config, settings);

    	var element = this;
    	
    	//абсолютно позиционируем виджет
    	element.css('position', 'absolute');
    	var curWindow = $(window);
    	updateElement();
    	
    	//изменяем положения виджета при прокрутке страницы 
    	curWindow.scroll(function() {
   			updateElement();
    	});
    	
    	function updateElement() {
    		//определяем размеры окна
    		var windowWidth = curWindow.width();
    		var windowTop = curWindow.scrollTop();
    		//рассчитываем положение виджета
    		var elementLeft = windowWidth / 2 - config.fromCenter - element.width() / 2;
    		var elementTop = windowTop + config.fromTop;
    		if (elementTop < config.minTop) {
    			elementTop = config.minTop;
    		}
    		
    		//изменяем CSS свойства left и top,
    		//в результате виджет будет перемещаеться
			element.css({'left':elementLeft, 'top':elementTop});
    	}
    };
})(jQuery);